@@ -15,7 +15,6 @@
 from datetime import datetime
 import json
 import logging
-import multiprocessing
 import os
 import shutil
 import six
@@ -46,47 +45,31 @@ def write_default_ansible_cfg(work_dir,
     ansible_config_path = os.path.join(work_dir, 'ansible.cfg')
     shutil.copy(base_ansible_cfg, ansible_config_path)
 
-    modules_path = (
-        '/root/.ansible/plugins/modules:'
-        '/usr/share/ansible/tripleo-plugins/modules:'
-        '/usr/share/ansible/plugins/modules:'
-        '{}/library:'
-        '{}/library'.format(constants.DEFAULT_VALIDATIONS_BASEDIR,
-                            constants.DEFAULT_VALIDATIONS_LEGACY_BASEDIR))
+    modules_path = ('/root/.ansible/plugins/modules:'
+                    '/usr/share/ansible/tripleo-plugins/modules:'
+                    '/usr/share/ansible/plugins/modules:'
+                    '%s/library' % constants.DEFAULT_VALIDATIONS_BASEDIR)
     lookups_path = (
         '/root/.ansible/plugins/lookup:'
         '/usr/share/ansible/tripleo-plugins/lookup:'
         '/usr/share/ansible/plugins/lookup:'
-        '{}/lookup_plugins:'
-        '{}/lookup_plugins'.format(
-            constants.DEFAULT_VALIDATIONS_BASEDIR,
-            constants.DEFAULT_VALIDATIONS_LEGACY_BASEDIR))
+        '%s/lookup_plugins' % constants.DEFAULT_VALIDATIONS_BASEDIR)
     callbacks_path = (
         '~/.ansible/plugins/callback:'
         '/usr/share/ansible/tripleo-plugins/callback:'
         '/usr/share/ansible/plugins/callback:'
-        '{}/callback_plugins:'
-        '{}/callback_plugins'.format(
-            constants.DEFAULT_VALIDATIONS_BASEDIR,
-            constants.DEFAULT_VALIDATIONS_LEGACY_BASEDIR))
-    callbacks_whitelist = ','.join(['tripleo_dense', 'tripleo_profile_tasks',
-                                    'tripleo_states'])
+        '%s/callback_plugins' % constants.DEFAULT_VALIDATIONS_BASEDIR)
+    callbacks_whitelist = ','.join(['profile_tasks'])
     action_plugins_path = (
         '~/.ansible/plugins/action:'
         '/usr/share/ansible/plugins/action:'
         '/usr/share/ansible/tripleo-plugins/action:'
-        '{}/action_plugins:'
-        '{}/action_plugins'.format(
-            constants.DEFAULT_VALIDATIONS_BASEDIR,
-            constants.DEFAULT_VALIDATIONS_LEGACY_BASEDIR))
+        '%s/action_plugins' % constants.DEFAULT_VALIDATIONS_BASEDIR)
     filter_plugins_path = (
         '~/.ansible/plugins/filter:'
         '/usr/share/ansible/plugins/filter:'
         '/usr/share/ansible/tripleo-plugins/filter:'
-        '{}/filter_plugins:'
-        '{}/filter_plugins'.format(
-            constants.DEFAULT_VALIDATIONS_BASEDIR,
-            constants.DEFAULT_VALIDATIONS_LEGACY_BASEDIR))
+        '%s/filter_plugins' % constants.DEFAULT_VALIDATIONS_BASEDIR)
     roles_path = ('%(work_dir)s/roles:'
                   '/root/.ansible/roles:'
                   '/usr/share/ansible/tripleo-roles:'
@@ -95,8 +78,7 @@ def write_default_ansible_cfg(work_dir,
                   '%(ooo_val_path)s/roles:'
                   '%(work_dir)s' % {
                       'work_dir': work_dir,
-                      'ooo_val_path':
-                          constants.DEFAULT_VALIDATIONS_LEGACY_BASEDIR
+                      'ooo_val_path': constants.DEFAULT_VALIDATIONS_BASEDIR
                   })
 
     config = configparser.ConfigParser()
@@ -107,7 +89,6 @@ def write_default_ansible_cfg(work_dir,
     config.set('defaults', 'library', modules_path)
     config.set('defaults', 'callback_plugins', callbacks_path)
     config.set('defaults', 'callback_whitelist', callbacks_whitelist)
-    config.set('defaults', 'stdout_callback', 'tripleo_dense')
     config.set('defaults', 'action_plugins', action_plugins_path)
     config.set('defaults', 'lookup_plugins', lookups_path)
     config.set('defaults', 'filter_plugins', filter_plugins_path)
@@ -119,13 +100,7 @@ def write_default_ansible_cfg(work_dir,
                     datetime.now().strftime("%Y-%m-%dT%H:%M:%S"))
         os.rename(log_path, new_path)
 
-    # Create the log file, and set some rights on it in order to prevent
-    # unwanted access
-    open(log_path, 'a').close()
-    os.chmod(log_path, 0o640)
-
-    config.set('defaults', 'forks', str(min(
-        multiprocessing.cpu_count() * 4, 100)))
+    config.set('defaults', 'forks', '25')
     config.set('defaults', 'timeout', '30')
     config.set('defaults', 'gather_timeout', '30')
 
@@ -133,18 +108,7 @@ def write_default_ansible_cfg(work_dir,
     config.set('defaults', 'gathering', 'smart')
     config.set('defaults', 'fact_caching', 'jsonfile')
     config.set('defaults', 'fact_caching_connection',
-               '~/.ansible/fact_cache')
-    # NOTE(mwhahaha): only gather the bare minimum facts because this has
-    # direct impact on how fast ansible can go.
-    config.set('defaults', 'gather_subset', '!all,min')
-    # NOTE(mwhahaha): this significantly affects performation per ansible#73654
-    config.set('defaults', 'inject_facts_as_vars', 'false')
-
-    # Set the pull interval to lower CPU overhead
-    config.set('defaults', 'internal_poll_interval', '0.05')
-
-    # Set the interpreter discovery to auto mode.
-    config.set('defaults', 'interpreter_python', 'auto')
+               '/var/lib/mistral/ansible_fact_cache')
 
     # Expire facts in the fact cache after 7200s (2h)
     config.set('defaults', 'fact_caching_timeout', '7200')
@@ -156,8 +120,7 @@ def write_default_ansible_cfg(work_dir,
                '-o ControlMaster=auto '
                '-o ControlPersist=30m '
                '-o ServerAliveInterval=5 '
-               '-o ServerAliveCountMax=5 '
-               '-o PreferredAuthentications=publickey')
+               '-o ServerAliveCountMax=5')
     config.set('ssh_connection', 'control_path_dir',
                os.path.join(work_dir, 'ansible-ssh'))
     config.set('ssh_connection', 'retries', '8')
@@ -176,10 +139,7 @@ def write_default_ansible_cfg(work_dir,
         sio_cfg = StringIO()
         sio_cfg.write(override_ansible_cfg)
         sio_cfg.seek(0)
-        if sys.version_info[0] < 3:
-            config.readfp(sio_cfg)  # pylint: disable=deprecated-method
-        else:
-            config.read_file(sio_cfg)
+        config.readfp(sio_cfg)
         sio_cfg.close()
 
     with open(ansible_config_path, 'w') as configfile:
@@ -225,14 +185,12 @@ class AnsibleAction(actions.Action):
         self.gather_facts = self._kwargs_for_run.pop('gather_facts', False)
 
         self._work_dir = None
-        self._remove_work_dir = False
 
     @property
     def work_dir(self):
         if self._work_dir:
             return self._work_dir
         self._work_dir = tempfile.mkdtemp(prefix='ansible-mistral-action')
-        self._remove_work_dir = True
         return self._work_dir
 
     @property
@@ -268,7 +226,6 @@ class AnsibleAction(actions.Action):
         # NOTE(flaper87): if it's a path, use it
         if (isinstance(self._ssh_private_key, six.string_types) and
                 os.path.exists(self._ssh_private_key)):
-            os.chmod(self._ssh_private_key, 0o600)
             return self._ssh_private_key
 
         path = os.path.join(self.work_dir, 'ssh_private_key')
@@ -365,13 +322,8 @@ class AnsibleAction(actions.Action):
                     "log_path": os.path.join(self.work_dir, 'ansible.log')}
         finally:
             # NOTE(flaper87): clean the mess if debug is disabled.
-            try:
-                if not self.verbosity and self._remove_work_dir:
-                    shutil.rmtree(self.work_dir)
-            except Exception as e:
-                msg = "An error happened while cleaning work directory: " + e
-                LOG.error(msg)
-                return actions.Result(error=msg)
+            if not self.verbosity:
+                shutil.rmtree(self.work_dir)
 
 
 class AnsiblePlaybookAction(base.TripleOAction):
@@ -423,7 +375,7 @@ class AnsiblePlaybookAction(base.TripleOAction):
         self.trash_output = self._kwargs_for_run.pop('trash_output', False)
         self.profile_tasks = self._kwargs_for_run.pop('profile_tasks', True)
         self.profile_tasks_limit = self._kwargs_for_run.pop(
-            'profile_tasks_limit', 20)
+            'profile_tasks_limit', 0)
         self.blacklisted_hostnames = self._kwargs_for_run.pop(
             'blacklisted_hostnames', [])
         self.override_ansible_cfg = self._kwargs_for_run.pop(
@@ -431,14 +383,11 @@ class AnsiblePlaybookAction(base.TripleOAction):
         self.command_timeout = self._kwargs_for_run.pop(
             'command_timeout', None)
 
-        self._remove_work_dir = False
-
     @property
     def work_dir(self):
         if self._work_dir:
             return self._work_dir
         self._work_dir = tempfile.mkdtemp(prefix='ansible-mistral-action')
-        self._remove_work_dir = True
         return self._work_dir
 
     @property
@@ -499,7 +448,6 @@ class AnsiblePlaybookAction(base.TripleOAction):
         # NOTE(flaper87): if it's a path, use it
         if (isinstance(self._ssh_private_key, six.string_types) and
                 os.path.exists(self._ssh_private_key)):
-            os.chmod(self._ssh_private_key, 0o600)
             return self._ssh_private_key
 
         path = os.path.join(self.work_dir, 'ssh_private_key')
@@ -551,21 +499,15 @@ class AnsiblePlaybookAction(base.TripleOAction):
         python_version = sys.version_info.major
         ansible_playbook_cmd = "ansible-playbook-{}".format(python_version)
 
-        if 1 < self.verbosity < 6:
-            verbosity_option = '-' + ('v' * (self.verbosity - 1))
+        if 0 < self.verbosity < 6:
+            verbosity_option = '-' + ('v' * self.verbosity)
             command = [ansible_playbook_cmd, verbosity_option,
                        self.playbook]
         else:
             command = [ansible_playbook_cmd, self.playbook]
 
-        # --limit should always take precedence over blacklisted hosts.
-        # https://bugzilla.redhat.com/show_bug.cgi?id=1857298
         if self.limit_hosts:
             command.extend(['--limit', self.limit_hosts])
-        elif self.blacklisted_hostnames:
-            host_pattern = ':'.join(
-                ['!%s' % h for h in self.blacklisted_hostnames if h])
-            command.extend(['--limit', host_pattern])
 
         if self.module_path:
             command.extend(['--module-path', self.module_path])
@@ -597,6 +539,11 @@ class AnsiblePlaybookAction(base.TripleOAction):
         if self.inventory:
             command.extend(['--inventory-file', self.inventory])
 
+        if self.blacklisted_hostnames:
+            host_pattern = ':'.join(
+                ['!%s' % h for h in self.blacklisted_hostnames])
+            command.extend(['--limit', host_pattern])
+
         if self.tags:
             command.extend(['--tags', self.tags])
 
@@ -630,9 +577,7 @@ class AnsiblePlaybookAction(base.TripleOAction):
                 env_variables.update({
                     # the whitelist could be collected from multiple
                     # arguments if we find a use case for it
-                    'ANSIBLE_CALLBACK_WHITELIST':
-                        'tripleo_dense,tripleo_profile_tasks,tripleo_states',
-                    'ANSIBLE_STDOUT_CALLBACK': 'tripleo_dense',
+                    'ANSIBLE_CALLBACK_WHITELIST': 'profile_tasks',
                     'PROFILE_TASKS_TASK_OUTPUT_LIMIT':
                         six.text_type(self.profile_tasks_limit),
                 })
@@ -666,8 +611,7 @@ class AnsiblePlaybookAction(base.TripleOAction):
                 os.chmod(command_path, 0o750)
 
             if self.command_timeout:
-                command = ['timeout', '-s', 'KILL',
-                           str(self.command_timeout)] + command
+                command = ['timeout', str(self.command_timeout)] + command
 
             if self.queue_name:
                 zaqar = self.get_messaging_client(context)
@@ -687,7 +631,7 @@ class AnsiblePlaybookAction(base.TripleOAction):
                     lines.append(line)
                     if not self.trash_output:
                         stdout.append(line)
-                    if time.time() - start > 5:
+                    if time.time() - start > 30:
                         self.post_message(queue, ''.join(lines))
                         lines = []
                         start = time.time()
@@ -714,13 +658,8 @@ class AnsiblePlaybookAction(base.TripleOAction):
                     "log_path": os.path.join(self.work_dir, 'ansible.log')}
         finally:
             # NOTE(flaper87): clean the mess if debug is disabled.
-            try:
-                if not self.verbosity and self._remove_work_dir:
-                    shutil.rmtree(self.work_dir)
-            except Exception as e:
-                msg = "An error happened while cleaning work directory: " + e
-                LOG.error(msg)
-                return actions.Result(error=msg)
+            if not self.verbosity:
+                shutil.rmtree(self.work_dir)
 
 
 class AnsibleGenerateInventoryAction(base.TripleOAction):
