@@ -284,10 +284,9 @@ class GeneratePasswordsAction(base.TripleOAction):
             # We don't modify these to avoid changing defaults
             for pw_res in constants.LEGACY_HEAT_PASSWORD_RESOURCE_NAMES:
                 try:
+                    res = heat.resources.get(self.container, pw_res)
                     param_defaults = stack_env.get('parameter_defaults', {})
-                    if pw_res not in param_defaults:
-                        res = heat.resources.get(self.container, pw_res)
-                        param_defaults[pw_res] = res.attributes['value']
+                    param_defaults[pw_res] = res.attributes['value']
                 except heat_exc.HTTPNotFound:
                     LOG.debug('Heat resouce not found: %s' % pw_res)
                     pass
@@ -295,18 +294,6 @@ class GeneratePasswordsAction(base.TripleOAction):
         except heat_exc.HTTPNotFound:
             stack_env = None
 
-        placement_extracted = False
-        try:
-            # We can't rely on the existence of PlacementPassword to
-            # determine if placement extraction has occured as it was added
-            # in stein while the service extraction was delayed to train.
-            # Inspect the endpoint map instead.
-            endpoint_res = heat.resources.get(self.container, 'EndpointMap')
-            endpoints = endpoint_res.attributes.get('endpoint_map', None)
-            placement_extracted = endpoints and 'PlacementPublic' in endpoints
-        except heat_exc.HTTPNotFound:
-            pass
-
         passwords = password_utils.generate_passwords(
             mistralclient=mistral,
             stack_env=stack_env,
@@ -324,15 +311,6 @@ class GeneratePasswordsAction(base.TripleOAction):
                 if i not in env['passwords']:
                     env['passwords'][i] = env['passwords']['RabbitPassword']
 
-        # NOTE(owalsh): placement previously used NovaPassword
-        # Default to the same password for PlacementPassword if it is an
-        # upgrade (i.e NovaPassword is set) so we do not need to update the
-        # password in keystone
-        if not placement_extracted and 'NovaPassword' in env['passwords']:
-            LOG.debug('Setting PlacementPassword to NovaPassword')
-            env['passwords']['PlacementPassword'] = \
-                env['passwords']['NovaPassword']
-
         # ensure all generated passwords are present in plan env,
         # but respect any values previously generated and stored
         for name, password in passwords.items():
@@ -447,13 +425,12 @@ class GenerateFencingParametersAction(base.TripleOAction):
 
             if driver_proto in {'ipmi', 'ipmitool', 'drac', 'idrac', 'ilo',
                                 'redfish'}:
+                # IPMI fencing driver
                 if driver_proto == "redfish":
                     node_data["agent"] = "fence_redfish"
                     params["systems_uri"] = node["pm_system_id"]
                 else:
                     node_data["agent"] = "fence_ipmilan"
-                    if self.ipmi_lanplus:
-                        params["lanplus"] = self.ipmi_lanplus
                 params["ipaddr"] = node["pm_addr"]
                 params["passwd"] = node["pm_password"]
                 params["login"] = node["pm_user"]
@@ -467,6 +444,8 @@ class GenerateFencingParametersAction(base.TripleOAction):
                         params["ssl_insecure"] = "true"
                     else:
                         params["ssl_insecure"] = "false"
+                if self.ipmi_lanplus:
+                    params["lanplus"] = self.ipmi_lanplus
                 if self.delay:
                     params["delay"] = self.delay
                 if self.ipmi_cipher:
@@ -703,16 +682,6 @@ class GetNetworkConfigAction(base.TripleOAction):
         if isinstance(processed_data, actions.Result):
             return processed_data
 
-        # Default temporary value is used when no user input for any
-        # interface routes for the role networks to find network config.
-        role_networks = processed_data['template'].get('resources', {}).get(
-            self.role_name + 'GroupVars', {}).get('properties', {}).get(
-                'value', {}).get('role_networks', [])
-        for nw in role_networks:
-            rt = nw + 'InterfaceRoutes'
-            if rt not in processed_data['environment']['parameter_defaults']:
-                processed_data['environment']['parameter_defaults'][rt] = [[]]
-
         # stacks.preview method raises validation message if stack is
         # already deployed. here renaming container to get preview data.
         container_temp = self.container + "-TEMP"
