@@ -48,6 +48,7 @@ _EXISTING_PASSWORDS = {
     'RabbitPassword': 'ahuHRXdPMx9rzCdjD9CJJNCgA',
     'RpcPassword': 'ahuHRXdPMx9rzCdjD9CJJNCgA',
     'NotifyPassword': 'ahuHRXdPMx9rzCdjD9CJJNCgA',
+    'CephAdminKey': b'AQCQXtlXAAAAABAAT4Gk+U8EqqStL+JFa9bp1Q==',
     'HAProxyStatsPassword': 'P8tbdK6n4YUkTaUyy8XgEVTe6',
     'CeilometerPassword': 'RRdpwK6qf2pbKz2UtzxqauAdk',
     'GnocchiPassword': 'cRYHcUkMuJeK3vyU9pCaznUZc',
@@ -61,7 +62,9 @@ _EXISTING_PASSWORDS = {
     'OctaviaCaKeyPassphrase': 'SLj4c3uCk4DDxPwQOG1Heb==',
     'ManilaPassword': 'NYJN86Fua3X8AVFWmMhQa2zTH',
     'NeutronMetadataProxySharedSecret': 'Q2YgUCwmBkYdqsdhhCF4hbghu',
+    'CephMdsKey': b'AQCQXtlXAAAAABAAT4Gk+U8EqqStL+JFa9bp1Q==',
     'CephManilaClientKey': b'AQANOFFY1NW6AxAAu6jWI3YSOsp2QWusb5Y3DQ==',
+    'CephMonKey': b'AQCQXtlXAAAAABAA9l+59N3yH+C49Y0JiKeGFg==',
     'CephGrafanaAdminPassword': 'NYJN86Fua3X8AVFWmMhQa2zTH',
     'CephDashboardAdminPassword': 'NYJN86Fua3X8AVFWmMhQa2zTH',
     'SwiftHashSuffix': 'td8mV6k7TYEGKCDvjVBwckpn9',
@@ -623,9 +626,6 @@ class GeneratePasswordsActionTest(base.TestCase):
         }
         mock_resource = mock.MagicMock()
         mock_resource.attributes = {
-            'endpoint_map': {
-                'PlacementPublic': {}
-            },
             'value': 'existing_value'
         }
         mock_orchestration.resources.get.return_value = mock_resource
@@ -695,14 +695,6 @@ class GeneratePasswordsActionTest(base.TestCase):
         mock_orchestration.stacks.environment.return_value = {
             'parameter_defaults': {}
         }
-        mock_resource = mock.MagicMock()
-        mock_resource.attributes = {
-            'endpoint_map': {
-                'PlacementPublic': {}
-            },
-            'value': None
-        }
-        mock_orchestration.resources.get.return_value = mock_resource
         mock_get_orchestration_client.return_value = mock_orchestration
 
         action = parameters.GeneratePasswordsAction()
@@ -716,68 +708,6 @@ class GeneratePasswordsActionTest(base.TestCase):
             "tripleo.parameters.get"
         )
 
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                'cache_delete')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                'get_orchestration_client')
-    @mock.patch('tripleo_common.utils.passwords.'
-                'create_ssh_keypair')
-    @mock.patch('tripleo_common.utils.passwords.'
-                'create_fernet_keys_repo_structure_and_keys')
-    @mock.patch('tripleo_common.utils.passwords.'
-                'get_snmpd_readonly_user_password')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                'get_workflow_client')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
-    def test_placement_passwords_upgrade(self, mock_get_object_client,
-                                         mock_get_workflow_client,
-                                         mock_get_snmpd_readonly_user_password,
-                                         mock_fernet_keys_setup,
-                                         mock_create_ssh_keypair,
-                                         mock_get_orchestration_client,
-                                         mock_cache):
-
-        mock_get_snmpd_readonly_user_password.return_value = "TestPassword"
-        mock_create_ssh_keypair.return_value = {'public_key': 'Foo',
-                                                'private_key': 'Bar'}
-        mock_fernet_keys_setup.return_value = {'/tmp/foo': {'content': 'Foo'},
-                                               '/tmp/bar': {'content': 'Bar'}}
-
-        passwords = _EXISTING_PASSWORDS.copy()
-
-        mock_ctx = mock.MagicMock()
-
-        swift = mock.MagicMock(url="http://test.com")
-        mock_env = yaml.safe_dump({
-            'name': constants.DEFAULT_CONTAINER_NAME,
-            'temp_environment': 'temp_environment',
-            'template': 'template',
-            'environments': [{u'path': u'environments/test.yaml'}],
-            'passwords': passwords
-        }, default_flow_style=False)
-        swift.get_object.return_value = ({}, mock_env)
-        mock_get_object_client.return_value = swift
-
-        mock_orchestration = mock.MagicMock()
-        mock_orchestration.stacks.environment.return_value = {
-            'parameter_defaults': {}
-        }
-        mock_resource = mock.MagicMock()
-        mock_resource.attributes = {
-            'endpoint_map': None,
-            'value': None
-        }
-        mock_orchestration.resources.get.return_value = mock_resource
-        mock_get_orchestration_client.return_value = mock_orchestration
-
-        action = parameters.GeneratePasswordsAction()
-        result = action.run(mock_ctx)
-
-        self.assertEqual(
-            passwords['NovaPassword'],
-            result['PlacementPassword']
-        )
-
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
                 'cache_delete')
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
@@ -822,11 +752,9 @@ class GeneratePasswordsActionTest(base.TestCase):
         mock_orchestration.stacks.environment.return_value = {
             'parameter_defaults': {}
         }
+
         mock_resource = mock.MagicMock()
         mock_resource.attributes = {
-            'endpoint_map': {
-                'PlacementPublic': {}
-            },
             'value': 'existing_value'
         }
         mock_orchestration.resources.get.return_value = mock_resource
@@ -897,9 +825,6 @@ class GeneratePasswordsActionTest(base.TestCase):
         }
         mock_resource = mock.MagicMock()
         mock_resource.attributes = {
-            'endpoint_map': {
-                'PlacementPublic': {}
-            },
             'value': 'existing_value'
         }
         mock_orchestration.resources.get.return_value = mock_resource
@@ -964,7 +889,6 @@ class GeneratePasswordsActionTest(base.TestCase):
 
         existing_passwords = _EXISTING_PASSWORDS.copy()
         existing_passwords.pop("AdminPassword")
-        existing_passwords.pop("PcsdPassword")
 
         mock_ctx = mock.MagicMock()
         swift = mock.MagicMock(url="http://test.com")
@@ -983,24 +907,14 @@ class GeneratePasswordsActionTest(base.TestCase):
         mock_orchestration.stacks.environment.return_value = {
             'parameter_defaults': {
                 'AdminPassword': 'ExistingPasswordInHeat',
-                'PcsdPassword': 'MyPassword',
             }
         }
-        mock_resource = mock.MagicMock()
-        mock_resource.attributes = {
-            'endpoint_map': {
-                'PlacementPublic': {}
-            },
-            'value': None
-        }
-        mock_orchestration.resources.get.return_value = mock_resource
         mock_get_orchestration_client.return_value = mock_orchestration
 
         action = parameters.GeneratePasswordsAction()
         result = action.run(mock_ctx)
 
         existing_passwords["AdminPassword"] = "ExistingPasswordInHeat"
-        existing_passwords["PcsdPassword"] = "MyPassword"
         # ensure old passwords used and no new generation
         self.assertEqual(existing_passwords, result)
         mock_cache.assert_called_once_with(
@@ -1030,14 +944,6 @@ class GetPasswordsActionTest(base.TestCase):
         mock_get_object_client.return_value = swift
 
         mock_orchestration = mock.MagicMock()
-        mock_resource = mock.MagicMock()
-        mock_resource.attributes = {
-            'endpoint_map': {
-                'PlacementPublic': {}
-            },
-            'value': None
-        }
-        mock_orchestration.resources.get.return_value = mock_resource
         mock_get_orchestration_client.return_value = mock_orchestration
 
         action = parameters.GetPasswordsAction()
@@ -1066,15 +972,6 @@ class GetPasswordsActionTest(base.TestCase):
         mock_get_object_client.return_value = swift
 
         mock_orchestration = mock.MagicMock()
-        mock_resource = mock.MagicMock()
-        mock_resource.attributes = {
-            'endpoint_map': {
-                'PlacementPublic': {}
-            },
-            'value': None
-        }
-        mock_orchestration.resources.get.return_value = mock_resource
-
         mock_get_orchestration_client.return_value = mock_orchestration
 
         action = parameters.GetPasswordsAction()
@@ -1106,14 +1003,6 @@ class GetPasswordsActionTest(base.TestCase):
         mock_get_object_client.return_value = swift
 
         mock_orchestration = mock.MagicMock()
-        mock_resource = mock.MagicMock()
-        mock_resource.attributes = {
-            'endpoint_map': {
-                'PlacementPublic': {}
-            },
-            'value': None
-        }
-        mock_orchestration.resources.get.return_value = mock_resource
         mock_get_orchestration_client.return_value = mock_orchestration
 
         action = parameters.GetPasswordsAction()
@@ -1255,6 +1144,7 @@ class GenerateFencingParametersActionTestCase(base.TestCase):
                              "delay": 28,
                              "ipaddr": "172.16.0.1:8000",
                              "ipport": "8000",
+                             "lanplus": True,
                              "privlvl": 5,
                              "login": "root",
                              "passwd": "calvin",
@@ -1612,151 +1502,6 @@ class GetNetworkConfigActionTest(base.TestCase):
             stack_name='overcloud-TEMP',
         )
 
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                'cache_set')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                'cache_get')
-    @mock.patch('heatclient.common.template_utils.'
-                'process_multiple_environments_and_files')
-    @mock.patch('heatclient.common.template_utils.get_template_contents')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                'get_orchestration_client')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                'get_workflow_client')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
-    def test_run_valid_network_config_with_no_interface_routes_inputs(
-            self, mock_get_object_client, mock_get_workflow_client,
-            mock_get_orchestration_client, mock_get_template_contents,
-            mock_process_multiple_environments_and_files,
-            mock_cache_get,
-            mock_cache_set):
-
-        mock_ctx = mock.MagicMock()
-        swift = mock.MagicMock(url="http://test.com")
-        mock_env = yaml.safe_dump({
-            'temp_environment': 'temp_environment',
-            'template': 'template',
-            'environments': [{u'path': u'environments/test.yaml'}]
-        }, default_flow_style=False)
-        swift.get_object.side_effect = (
-            ({}, mock_env),
-            swiftexceptions.ClientException('atest2'),
-            ({}, mock_env)
-        )
-        mock_get_object_client.return_value = swift
-
-        mock_get_template_contents.return_value = ({}, {
-            'heat_template_version': '2016-04-30',
-            'resources': {'ComputeGroupVars': {'properties': {
-                'value': {'role_networks': ['InternalApi', 'Storage']}
-                }
-            }}
-        })
-        mock_process_multiple_environments_and_files.return_value = (
-            {}, {'parameter_defaults': {}})
-
-        mock_heat = mock.MagicMock()
-        mock_heat.stacks.preview.return_value = mock.Mock(resources=[{
-            "resource_identity": {"stack_name": "overcloud-TEMP-Compute-0"},
-            "resource_name": "OsNetConfigImpl",
-            "properties": {"config": "echo \'{\"network_config\": {}}\'"
-                           " > /etc/os-net-config/config.json"}
-            }])
-
-        mock_get_orchestration_client.return_value = mock_heat
-
-        mock_cache_get.return_value = None
-        expected = {"network_config": {}}
-        # Test
-        action = parameters.GetNetworkConfigAction(container='overcloud',
-                                                   role_name='Compute')
-        result = action.run(mock_ctx)
-        self.assertEqual(expected, result)
-        mock_heat.stacks.preview.assert_called_once_with(
-            environment={'parameter_defaults': {
-                'InternalApiInterfaceRoutes': [[]],
-                'StorageInterfaceRoutes': [[]]}},
-            files={},
-            template={'heat_template_version': '2016-04-30',
-                      'resources': {'ComputeGroupVars': {
-                          'properties': {'value': {
-                              'role_networks': ['InternalApi',
-                                                'Storage']}}}}},
-            stack_name='overcloud-TEMP',
-        )
-
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                'cache_set')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                'cache_get')
-    @mock.patch('heatclient.common.template_utils.'
-                'process_multiple_environments_and_files')
-    @mock.patch('heatclient.common.template_utils.get_template_contents')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                'get_orchestration_client')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                'get_workflow_client')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
-    def test_run_valid_network_config_with_interface_routes_inputs(
-            self, mock_get_object_client, mock_get_workflow_client,
-            mock_get_orchestration_client, mock_get_template_contents,
-            mock_process_multiple_environments_and_files,
-            mock_cache_get,
-            mock_cache_set):
-
-        mock_ctx = mock.MagicMock()
-        swift = mock.MagicMock(url="http://test.com")
-        mock_env = yaml.safe_dump({
-            'temp_environment': 'temp_environment',
-            'template': 'template',
-            'environments': [{u'path': u'environments/test.yaml'}]
-        }, default_flow_style=False)
-        swift.get_object.side_effect = (
-            ({}, mock_env),
-            swiftexceptions.ClientException('atest2'),
-            ({}, mock_env)
-        )
-        mock_get_object_client.return_value = swift
-
-        mock_get_template_contents.return_value = ({}, {
-            'heat_template_version': '2016-04-30',
-            'resources': {'ComputeGroupVars': {'properties': {
-                'value': {'role_networks': ['InternalApi', 'Storage']}}}}
-        })
-        mock_process_multiple_environments_and_files.return_value = (
-            {}, {'parameter_defaults': {
-                'InternalApiInterfaceRoutes': ['test1'],
-                'StorageInterfaceRoutes': ['test2']}})
-
-        mock_heat = mock.MagicMock()
-        mock_heat.stacks.preview.return_value = mock.Mock(resources=[{
-            "resource_identity": {"stack_name": "overcloud-TEMP-Compute-0"},
-            "resource_name": "OsNetConfigImpl",
-            "properties": {"config": "echo \'{\"network_config\": {}}\'"
-                           " > /etc/os-net-config/config.json"}
-            }])
-
-        mock_get_orchestration_client.return_value = mock_heat
-
-        mock_cache_get.return_value = None
-        expected = {"network_config": {}}
-        # Test
-        action = parameters.GetNetworkConfigAction(container='overcloud',
-                                                   role_name='Compute')
-        result = action.run(mock_ctx)
-        self.assertEqual(expected, result)
-        mock_heat.stacks.preview.assert_called_once_with(
-            environment={'parameter_defaults': {
-                'InternalApiInterfaceRoutes': ['test1'],
-                'StorageInterfaceRoutes': ['test2']}},
-            files={},
-            template={'heat_template_version': '2016-04-30',
-                      'resources': {'ComputeGroupVars': {'properties': {
-                          'value': {'role_networks': ['InternalApi',
-                                                      'Storage']}}}}},
-            stack_name='overcloud-TEMP',
-        )
-
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
                 'cache_set')
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
