@@ -36,12 +36,12 @@ from tripleo_common.tests.image import fakes
 
 filedata = six.u(
     """container_images:
-    - imagename: docker.io/tripleotrain/heat-docker-agents-centos:latest
+    - imagename: docker.io/tripleomaster/heat-docker-agents-centos:latest
       push_destination: localhost:8787
-    - imagename: docker.io/tripleotrain/centos-binary-nova-compute:liberty
+    - imagename: docker.io/tripleomaster/centos-binary-nova-compute:liberty
       push_destination: localhost:8787
-    - imagename: docker.io/tripleotrain/centos-binary-nova-libvirt:liberty
-    - imagename: docker.io/tripleotrain/image-with-missing-tag
+    - imagename: docker.io/tripleomaster/centos-binary-nova-libvirt:liberty
+    - imagename: docker.io/tripleomaster/image-with-missing-tag
       push_destination: localhost:8787
 """)
 
@@ -1260,10 +1260,10 @@ class TestPythonImageUploader(base.TestCase):
         })
         _fetch_manifest.return_value = manifest
 
-        image = 'docker.io/tripleotrain/heat-docker-agents-centos'
+        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
         tag = 'latest'
         push_destination = 'localhost:8787'
-        # push_image = 'localhost:8787/tripleotrain/heat-docker-agents-centos'
+        # push_image = 'localhost:8787/tripleomaster/heat-docker-agents-centos'
         task = image_uploader.UploadTask(
             image_name=image + ':' + tag,
             pull_source=None,
@@ -1280,9 +1280,9 @@ class TestPythonImageUploader(base.TestCase):
             [],
             self.uploader.upload_image(task)
         )
-        source_url = urlparse('docker://docker.io/tripleotrain/'
+        source_url = urlparse('docker://docker.io/tripleomaster/'
                               'heat-docker-agents-centos:latest')
-        target_url = urlparse('docker://localhost:8787/tripleotrain/'
+        target_url = urlparse('docker://localhost:8787/tripleomaster/'
                               'heat-docker-agents-centos:latest')
 
         authenticate.assert_has_calls([
@@ -1357,10 +1357,10 @@ class TestPythonImageUploader(base.TestCase):
         })
         _fetch_manifest.return_value = manifest
 
-        image = 'docker.io/tripleotrain/heat-docker-agents-centos'
+        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
         tag = 'latest'
         push_destination = 'localhost:8787'
-        # push_image = 'localhost:8787/tripleotrain/heat-docker-agents-centos'
+        # push_image = 'localhost:8787/tripleomaster/heat-docker-agents-centos'
         task = image_uploader.UploadTask(
             image_name=image + ':' + tag,
             pull_source=None,
@@ -1377,9 +1377,9 @@ class TestPythonImageUploader(base.TestCase):
             [],
             self.uploader.upload_image(task)
         )
-        source_url = urlparse('docker://docker.io/tripleotrain/'
+        source_url = urlparse('docker://docker.io/tripleomaster/'
                               'heat-docker-agents-centos:latest')
-        target_url = urlparse('docker://localhost:8787/tripleotrain/'
+        target_url = urlparse('docker://localhost:8787/tripleomaster/'
                               'heat-docker-agents-centos:latest')
 
         authenticate.assert_has_calls([
@@ -1426,10 +1426,10 @@ class TestPythonImageUploader(base.TestCase):
         })
         _fetch_manifest.return_value = manifest
 
-        image = '192.0.2.0:8787/tripleotrain/heat-docker-agents-centos'
+        image = '192.0.2.0:8787/tripleomaster/heat-docker-agents-centos'
         tag = 'latest'
         push_destination = 'localhost:8787'
-        # push_image = 'localhost:8787/tripleotrain/heat-docker-agents-centos'
+        # push_image = 'localhost:8787/tripleomaster/heat-docker-agents-centos'
         task = image_uploader.UploadTask(
             image_name=image + ':' + tag,
             pull_source=None,
@@ -1446,9 +1446,9 @@ class TestPythonImageUploader(base.TestCase):
             [],
             self.uploader.upload_image(task)
         )
-        source_url = urlparse('docker://192.0.2.0:8787/tripleotrain/'
+        source_url = urlparse('docker://192.0.2.0:8787/tripleomaster/'
                               'heat-docker-agents-centos:latest')
-        target_url = urlparse('docker://localhost:8787/tripleotrain/'
+        target_url = urlparse('docker://localhost:8787/tripleomaster/'
                               'heat-docker-agents-centos:latest')
 
         authenticate.assert_has_calls([
@@ -1494,10 +1494,10 @@ class TestPythonImageUploader(base.TestCase):
         })
         _fetch_manifest.return_value = manifest
 
-        image = 'docker.io/tripleotrain/heat-docker-agents-centos'
+        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
         tag = 'latest'
         push_destination = 'localhost:8787'
-        # push_image = 'localhost:8787/tripleotrain/heat-docker-agents-centos'
+        # push_image = 'localhost:8787/tripleomaster/heat-docker-agents-centos'
         task = image_uploader.UploadTask(
             image_name=image + ':' + tag,
             pull_source=None,
@@ -1514,9 +1514,9 @@ class TestPythonImageUploader(base.TestCase):
             [],
             self.uploader.upload_image(task)
         )
-        source_url = urlparse('docker://docker.io/tripleotrain/'
+        source_url = urlparse('docker://docker.io/tripleomaster/'
                               'heat-docker-agents-centos:latest')
-        target_url = urlparse('docker://localhost:8787/tripleotrain/'
+        target_url = urlparse('docker://localhost:8787/tripleomaster/'
                               'heat-docker-agents-centos:latest')
 
         authenticate.assert_has_calls([
@@ -1600,11 +1600,11 @@ class TestPythonImageUploader(base.TestCase):
         })
         _fetch_manifest.return_value = manifest
 
-        image = 'docker.io/tripleotrain/heat-docker-agents-centos'
+        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
         tag = 'latest'
         append_tag = 'modify-123'
         push_destination = 'localhost:8787'
-        # push_image = 'localhost:8787/tripleotrain/heat-docker-agents-centos'
+        # push_image = 'localhost:8787/tripleomaster/heat-docker-agents-centos'
         task = image_uploader.UploadTask(
             image_name=image + ':' + tag,
             pull_source=None,
@@ -1618,22 +1618,22 @@ class TestPythonImageUploader(base.TestCase):
         )
 
         source_url = urlparse(
-            'docker://docker.io/tripleotrain/'
+            'docker://docker.io/tripleomaster/'
             'heat-docker-agents-centos:latest')
         unmodified_target_url = urlparse(
-            'docker://localhost:8787/tripleotrain/'
+            'docker://localhost:8787/tripleomaster/'
             'heat-docker-agents-centos:latest')
         local_modified_url = urlparse(
-            'containers-storage:localhost:8787/tripleotrain/'
+            'containers-storage:localhost:8787/tripleomaster/'
             'heat-docker-agents-centos:latestmodify-123')
         target_url = urlparse(
-            'docker://localhost:8787/tripleotrain/'
+            'docker://localhost:8787/tripleomaster/'
             'heat-docker-agents-centos:latestmodify-123')
 
         self.assertEqual([
-            'localhost:8787/tripleotrain/'
+            'localhost:8787/tripleomaster/'
             'heat-docker-agents-centos:latest',
-            'localhost:8787/tripleotrain/'
+            'localhost:8787/tripleomaster/'
             'heat-docker-agents-centos:latestmodify-123'],
             self.uploader.upload_image(task)
         )
@@ -1689,9 +1689,9 @@ class TestPythonImageUploader(base.TestCase):
         run_modify_playbook.assert_called_once_with(
             'add-foo-plugin',
             {'foo_version': '1.0.1'},
-            'localhost:8787/tripleotrain/'
+            'localhost:8787/tripleomaster/'
             'heat-docker-agents-centos:latest',
-            'localhost:8787/tripleotrain/'
+            'localhost:8787/tripleomaster/'
             'heat-docker-agents-centos:latest',
             'modify-123',
             container_build_tool='buildah'
@@ -1719,7 +1719,7 @@ class TestPythonImageUploader(base.TestCase):
             target_session
         ]
 
-        image = 'docker.io/tripleotrain/heat-docker-agents-centos'
+        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
         tag = 'latest'
         push_destination = 'localhost:8787'
         source_image = 'containers-storage:%s:%s' % (image, tag)
@@ -1740,7 +1740,7 @@ class TestPythonImageUploader(base.TestCase):
             self.uploader.upload_image(task)
         )
         source_url = urlparse(source_image)
-        target_url = urlparse('docker://localhost:8787/tripleotrain/'
+        target_url = urlparse('docker://localhost:8787/tripleomaster/'
                               'heat-docker-agents-centos:latest')
         authenticate.assert_has_calls([
             mock.call(
@@ -2348,49 +2348,6 @@ class TestPythonImageUploader(base.TestCase):
             self.uploader._inspect(url)
         )
 
-    @mock.patch('tripleo_common.image.image_uploader.'
-                'PythonImageUploader._image_manifest_config')
-    def test_inspect_no_labels(self, _image_manifest_config):
-        url = urlparse('containers-storage:/t/nova-api:latest')
-        config = {
-            'config': {},
-            'architecture': 'x86_64',
-            'os': 'linux'
-        }
-        _image_manifest_config.return_value = (
-            {
-                'id': 'cccc',
-                'digest': 'sha256:ccccc',
-                'names': ['192.168.2.1:5000/t/nova-api:latest'],
-                'created': '2018-10-02T11:13:45.567533229Z'
-            }, {
-                'config': {
-                    'digest': 'sha256:1234',
-                },
-                'layers': [
-                    {'digest': 'sha256:aaa'},
-                    {'digest': 'sha256:bbb'},
-                    {'digest': 'sha256:ccc'}
-                ],
-            },
-            json.dumps(config)
-        )
-
-        self.assertEqual(
-            {
-                'Name': '/t/nova-api',
-                'Architecture': 'x86_64',
-                'Created': '2018-10-02T11:13:45.567533229Z',
-                'Digest': 'sha256:ccccc',
-                'DockerVersion': '',
-                'Labels': {},
-                'Layers': ['sha256:aaa', 'sha256:bbb', 'sha256:ccc'],
-                'Os': 'linux',
-                'RepoTags': []
-            },
-            self.uploader._inspect(url)
-        )
-
     @mock.patch('os.environ')
     @mock.patch('subprocess.Popen')
     def test_delete(self, mock_popen, mock_environ):
