@@ -50,26 +50,20 @@ class TestConfig(base.TestCase):
                             'service_metadata_settings',
                             'service_names',
                             'upgrade_batch_tasks', 'upgrade_tasks',
-                            'external_deploy_steps_tasks']
+                            'external_deploy_tasks']
+        fake_role = [role for role in
+                     fakes.FAKE_STACK['outputs'][1]['output_value']]
 
         heat = mock.MagicMock()
         heat.stacks.get.return_value = fakes.create_tht_stack()
         self.config = ooo_config.Config(heat)
-        self.config.fetch_config('overcloud')
-        fake_role = list(self.config.stack_outputs.get('RoleData'))
         self.config.download_config('overcloud', '/tmp/tht', config_type_list)
 
         mock_git_init.assert_called_once_with('/tmp/tht')
         expected_mkdir_calls = [call('/tmp/tht/%s' % r) for r in fake_role]
         mock_mkdir.assert_has_calls(expected_mkdir_calls, any_order=True)
-        mock_mkdir.assert_called()
         expected_calls = []
         for config in config_type_list:
-            if 'external' in config:
-                for step in range(constants.DEFAULT_STEPS_MAX):
-                    expected_calls += [call('/tmp/tht/%s_step%s.yaml' %
-                                       (config, step))]
-
             for role in fake_role:
                 if 'external' in config:
                     continue
@@ -97,12 +91,12 @@ class TestConfig(base.TestCase):
                                               mock_git_init):
 
         expected_config_type = 'config_settings'
+        fake_role = [role for role in
+                     fakes.FAKE_STACK['outputs'][1]['output_value']]
 
         heat = mock.MagicMock()
         heat.stacks.get.return_value = fakes.create_tht_stack()
         self.config = ooo_config.Config(heat)
-        self.config.fetch_config('overcloud')
-        fake_role = list(self.config.stack_outputs.get('RoleData'))
         self.config.download_config('overcloud', '/tmp/tht',
                                     ['config_settings'])
         expected_mkdir_calls = [call('/tmp/tht/%s' % r) for r in fake_role]
@@ -110,7 +104,6 @@ class TestConfig(base.TestCase):
                           % (r, expected_config_type))
                           for r in fake_role]
         mock_mkdir.assert_has_calls(expected_mkdir_calls, any_order=True)
-        mock_mkdir.assert_called()
         mock_open.assert_has_calls(expected_calls, any_order=True)
         mock_git_init.assert_called_once_with('/tmp/tht')
 
@@ -135,9 +128,9 @@ class TestConfig(base.TestCase):
         heat = mock.MagicMock()
         heat.stacks.get.return_value = fakes.create_tht_stack()
         self.config = ooo_config.Config(heat)
-        self.config.fetch_config('overcloud')
         self.tmp_dir = self.useFixture(fixtures.TempDir()).path
-        fake_role = list(self.config.stack_outputs.get('RoleData'))
+        fake_role = [role for role in
+                     fakes.FAKE_STACK['outputs'][1]['output_value']]
         expected_tasks = {'FakeController': {0: [],
                                              1: [{'name': 'Stop fake service',
                                                   'service': 'name=fake '
@@ -152,7 +145,7 @@ class TestConfig(base.TestCase):
                                                'service': 'name=fake '
                                                'state=stopped',
                                                'when': ['nova_api_enabled.rc'
-                                                        ' == 0', False,
+                                                        ' == 0',
                                                         'httpd_enabled.rc'
                                                         ' != 0',
                                                         'step|int == 1']}],
@@ -171,12 +164,12 @@ class TestConfig(base.TestCase):
         for role in fake_role:
             filedir = os.path.join(self.tmp_dir, role)
             os.makedirs(filedir)
-            for step in range(constants.DEFAULT_STEPS_MAX):
+            for step in range(constants.UPGRADE_STEPS_MAX):
                 filepath = os.path.join(filedir, "upgrade_tasks_step%s.yaml"
                                         % step)
                 playbook_tasks = self.config._write_tasks_per_step(
-                    self.config.stack_outputs.get('RoleData')[role]
-                    ['upgrade_tasks'], filepath, step)
+                    fakes.FAKE_STACK['outputs'][1]['output_value'][role]
+                    ['upgrade_tasks'], role, filepath, step)
                 self.assertTrue(os.path.isfile(filepath))
                 self.assertEqual(expected_tasks[role][step], playbook_tasks)
 
@@ -322,19 +315,10 @@ class TestConfig(base.TestCase):
                          'uuid': 2},
                      'overcloud-novacompute-2': {
                          'uuid': 3}}}},
-            {'output_key': 'RoleData',
-             'output_value': {
-                 'Controller': {
-                     'ansible_group_vars': {
-                         'chrony_host': 'localhost',
-                         'chrony_acl': 'none',
-                     }}}},
             {'output_key': 'RoleGroupVars',
              'output_value': {
                  'Controller': {
                      'any_errors_fatal': True,
-                     'chrony_host': '192.168.2.1',
-                     'chrony_foo': 'bar',
                      'max_fail_percentage': 15},
                  'Compute': {
                      'any_errors_fatal': True,
@@ -656,13 +640,13 @@ class TestConfig(base.TestCase):
                             'service_names',
                             'upgrade_batch_tasks', 'upgrade_tasks',
                             'external_deploy_tasks']
+        fake_role = [role for role in
+                     fakes.FAKE_STACK['outputs'][1]['output_value']]
 
         mock_os_path_exists.get.return_value = True
         heat = mock.MagicMock()
         heat.stacks.get.return_value = fakes.create_tht_stack()
         self.config = ooo_config.Config(heat)
-        self.config.fetch_config('overcloud')
-        fake_role = list(self.config.stack_outputs.get('RoleData'))
         self.config.download_config('overcloud', '/tmp/tht', config_type_list,
                                     False)
 
@@ -672,7 +656,6 @@ class TestConfig(base.TestCase):
 
         expected_mkdir_calls = [call('/tmp/tht/%s' % r) for r in fake_role]
         mock_mkdir.assert_has_calls(expected_mkdir_calls, any_order=True)
-        mock_mkdir.assert_called()
         expected_calls = []
         for config in config_type_list:
             for role in fake_role:
@@ -736,19 +719,10 @@ class TestConfig(base.TestCase):
                          'a7db3010-a51f-4ae0-a791-2364d629d20d',
                          '8b07cd31-3083-4b88-a433-955f72039e2c',
                          '169b46f8-1965-4d90-a7de-f36fb4a830fe']}}},
-            {'output_key': 'RoleData',
-             'output_value': {
-                 'Controller': {
-                     'ansible_group_vars': {
-                         'chrony_host': 'localhost',
-                         'chrony_acl': 'none',
-                     }}}},
             {'output_key': 'RoleGroupVars',
              'output_value': {
                  'Controller': {
                      'any_errors_fatal': True,
-                     'chrony_host': '192.168.2.1',
-                     'chrony_foo': 'bar',
                      'max_fail_percentage': 15},
                  'Compute': {
                      'any_errors_fatal': True,
@@ -880,8 +854,7 @@ class TestConfig(base.TestCase):
         self.config = ooo_config.Config(heat)
         stack = mock.Mock()
         server_roles = dict(Controller='controller')
-        mock_get_network_config_data.return_value = dict(
-            Controller='56f27b7a-7bb8-40bc-bfdb-a46f7f806b88')
+        mock_get_network_config_data.return_value = dict(Controller='config')
         config_dir = '/tmp/tht'
         self.config.render_network_config(stack, config_dir, server_roles)
 
@@ -899,9 +872,8 @@ class TestConfig(base.TestCase):
         self.config = ooo_config.Config(heat)
         stack = mock.Mock()
         server_roles = dict(node1='Controller')
-        mock_get_network_config_data.return_value = dict(
-            node1='56f27b7a-7bb8-40bc-bfdb-a46f7f806b88',
-            node2='56f27b7a-7bb8-40bc-bfdb-a46f7f806b88')
+        mock_get_network_config_data.return_value = dict(node1='config',
+                                                         node2='config')
         config_dir = '/tmp/tht'
         self.config.render_network_config(stack, config_dir, server_roles)
         self.assertEqual(2, mock_open.call_count)
@@ -909,107 +881,3 @@ class TestConfig(base.TestCase):
                          mock_open.call_args_list[0][0][0])
         self.assertEqual('/tmp/tht/Controller/NetworkConfig',
                          mock_open.call_args_list[1][0][0])
-
-    @patch.object(ooo_config.Config, '_open_file')
-    def test_overcloud_config__write_tasks_per_step(self, mock_open_file):
-        heat = mock.MagicMock()
-        self.config = ooo_config.Config(heat)
-
-        # TODO: how can I share this tasks definition between to test
-        # as a fixture So that I do two several test cases instead of
-        # a big one.
-        tasks = [
-            {
-                "when": "step|int == 0",
-                "name": "Simple check"
-            },
-            {
-                "when": "(step|int == 0)",
-                "name": "Check within parenthesis"
-            },
-            {
-                "when": ["step|int == 0", "test1", False],
-                "name": "Check with list with boolean"
-            },
-            {
-                "when": ["test1", False, "step|int == 0"],
-                "name": "Check with list with boolean other order"
-            },
-            {
-                "when": "step|int == 0 or step|int == 3",
-                "name": "Check with boolean expression"
-            },
-            {
-                "when": "(step|int == 0 or step|int == 3) and other_cond",
-                "name": "Complex boolean expression"
-            },
-            {
-                "name": "Task with no conditional"
-            }
-        ]
-
-        # Everything should come back
-        tasks_per_step = self.config._write_tasks_per_step(
-            tasks,
-            'Compute/update_tasks_step0.yaml',
-            0
-        )
-
-        self.assertEqual(tasks, tasks_per_step)
-
-        # Using stict the tasks with no conditional will be dropped
-        tasks_per_step = self.config._write_tasks_per_step(
-            tasks,
-            'Compute/update_tasks_step0.yaml',
-            0,
-            strict=True,
-        )
-
-        expected_tasks = [task for task in tasks
-                          if task != {"name": "Task with no conditional"}]
-        self.assertEqual(expected_tasks,
-                         tasks_per_step)
-
-        # Some tasks will be filtered out for step 3.
-        tasks_per_step = self.config._write_tasks_per_step(
-            tasks,
-            'Compute/update_tasks_step3.yaml',
-            3
-        )
-
-        self.assertEqual(
-            [
-                {
-                    "when": "step|int == 0 or step|int == 3",
-                    "name": "Check with boolean expression"
-                },
-                {
-                    "when": "(step|int == 0 or step|int == 3) and other_cond",
-                    "name": "Complex boolean expression"
-                },
-                {
-                    "name": "Task with no conditional"
-                }
-            ],
-            tasks_per_step)
-
-        # Even more tasks will be filtered out for step 3 with strict.
-        tasks_per_step = self.config._write_tasks_per_step(
-            tasks,
-            'Compute/update_tasks_step3.yaml',
-            3,
-            strict=True,
-        )
-
-        self.assertEqual(
-            [
-                {
-                    "when": "step|int == 0 or step|int == 3",
-                    "name": "Check with boolean expression"
-                },
-                {
-                    "when": "(step|int == 0 or step|int == 3) and other_cond",
-                    "name": "Complex boolean expression"
-                },
-            ],
-            tasks_per_step)
