@@ -17,11 +17,6 @@ from six.moves import urllib
 from tripleo_common import constants
 from tripleo_common.utils import common as common_utils
 
-try:  # py3
-    from shlex import quote
-except ImportError:  # py2
-    from pipes import quote
-
 
 def get_service_ips(stack):
     service_ips = {}
@@ -76,12 +71,8 @@ def create_overcloudrc(stack, no_proxy, admin_password, region_name):
     overcloud_host = urllib.parse.urlparse(overcloud_endpoint).hostname
     overcloud_admin_vip = get_endpoint('KeystoneAdmin', stack)
 
-    no_proxy_list = no_proxy.split(',')
     no_proxy_list = map(common_utils.bracket_ipv6,
-                        no_proxy_list + [overcloud_host, overcloud_admin_vip])
-
-    # Remove duplicated entries
-    no_proxy_list = sorted(list(set(no_proxy_list)))
+                        [no_proxy, overcloud_host, overcloud_admin_vip])
 
     rc_params = {
         'NOVA_VERSION': '1.1',
@@ -93,8 +84,8 @@ def create_overcloudrc(stack, no_proxy, admin_password, region_name):
         'OS_NO_CACHE': 'True',
         'OS_CLOUDNAME': stack.stack_name,
         'no_proxy': ','.join(no_proxy_list),
-        'PYTHONWARNINGS': ('ignore:Certificate has no, ignore:A true '
-                           'SSLContext object is not available'),
+        'PYTHONWARNINGS': ('"ignore:Certificate has no, ignore:A true '
+                           'SSLContext object is not available"'),
         'OS_AUTH_TYPE': 'password',
         'OS_PASSWORD': admin_password,
         'OS_AUTH_URL': overcloud_endpoint.replace('/v2.0', ''),
@@ -107,8 +98,7 @@ def create_overcloudrc(stack, no_proxy, admin_password, region_name):
 
     overcloudrc = CLEAR_ENV
     for key, value in rc_params.items():
-        line = "export %(key)s=%(value)s\n" % {'key': key,
-                                               'value': quote(value)}
+        line = "export %(key)s=%(value)s\n" % {'key': key, 'value': value}
         overcloudrc = overcloudrc + line
     overcloudrc = overcloudrc + CLOUDPROMPT
 
